@@ -24,7 +24,6 @@ sub first {
         type => $self->type,
         id   => $self->ids->[0],
     );
-
 }
 
 sub next {
@@ -39,4 +38,8 @@ sub next {
     }
 }
 
+sub elems {
+    scalar @{ shift->ids }
+}
+
 1;
